bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.set_parameters
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.set_parameters